import time
from neopixel import *
from PIL import Image
import sys

# see also https://learn.adafruit.com/neopixels-on-raspberry-pi/overview

# LED strip configuration:
LED_COUNT   = 50      # Number of LED pix.
LED_PIN     = 18      # GPIO pin connected to the pix (must support PWM!).
LED_FREQ_HZ = 800000  # LED signal frequency in hertz (usually 800khz)
LED_DMA     = 5       # DMA channel to use for generating signal (try 5)
LED_INVERT  = False   # True to invert the signal (when using NPN transistor level shift)

# method to blank all LEDs
def blankLine():
    for x in range(LED_COUNT):
	strip.setPixelColorRGB(x, 0,0,0)
    strip.show()

# method to resize picture and show in column per column on the led strip
def showPicture(filename, strip):
    blankLine()
    # open file
    img = Image.open(filename).convert("RGB")

    # resize file
    newWidth = float(img.size[0])/float(img.size[1])*LED_COUNT
    img = img.resize( (int(newWidth), LED_COUNT))

    width = img.size[0]
    height = img.size[1]

    pix = img.load()

    for x in range(width):
	for y in range(height):
	    strip.setPixelColorRGB(y, pix[x,y][0], pix[x,y][1], pix[x,y][2])
	strip.show()
	time.sleep(0.3)

    blankLine()

# main function - start of the program - you have to provide an image name as an argument
# Create NeoPixel object with appropriate configuration.
strip = Adafruit_NeoPixel(LED_COUNT, LED_PIN, LED_FREQ_HZ, LED_DMA, LED_INVERT)
# Intialize the library (must be called once before other functions).
strip.begin()
showPicture( sys.argv[1], strip)
